"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _logger = require("../logger");

const config = require("../config");

class Backoff {
  constructor() {
    this._connectTime = null;

    this._resetBackoff();
  }

  async afterDisconnect() {
    if (this._connectTime !== null && Date.now() > this._connectTime + config.AgentComConfiguration.RESET_BACKOFF_TIMEOUT) {
      this._resetBackoff();
    }

    this._connectTime = null;

    _logger.logger.debug(`Backing off ${this._nextBackoff} seconds`);

    await this._timeout(this._nextBackoff);
    this._nextBackoff = Math.min(this._nextBackoff * 2, config.AgentComConfiguration.MAX_SLEEP);
  }

  afterConnect() {
    this._connectTime = Date.now();
  }

  _timeout(ms) {
    return new Promise(resolve => setTimeout(resolve, ms * 1000).unref());
  }

  _resetBackoff() {
    this._nextBackoff = config.AgentComConfiguration.BACK_OFF;
  }

}

exports.default = Backoff;
//# sourceMappingURL=backoff.js.map